PCB Environment: dsn::BBox Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::BBox Struct Reference

## Public Member Functions
double | minExtent () const
double | maxExtent () const

## Data Fields
double | xmin
double | ymin
double | xmax
double | ymax

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp